@@ -1,7 +1,5 @@
-import optparse
 from pathlib import Path
 from sys import exit, stderr
-from typing import List
 
 import json5 as json
 from cerberus import Validator
@@ -37,12 +35,8 @@ def check_raw_clock(d) -> None:
             raise FileNotFoundError(f"clock file err: {sound['sound_filename']} is not found.")
 
 
-def main(opt: optparse.Values, args: List[str]) -> None:
-    if len(args) != 1:
-        print('Length of argument should be 1.', file=stderr)
-        exit(1)
-
-    json_filename = get_real_json_filename(args[0])
+def main(clock_filename) -> None:
+    json_filename = get_real_json_filename(clock_filename)
     try:
         with open(json_filename) as f:
             jdata = json.load(f)
@@ -50,7 +44,7 @@ def main(opt: optparse.Values, args: List[str]) -> None:
         print(f'{json_filename} is Incorrect format for json5:\n' + f'{err.args[0]}', file=stderr)
         exit(1)
     except FileNotFoundError:
-        print(f'{args[0]} is not found.', file=stderr)
+        print(f'{clock_filename} is not found.', file=stderr)
         exit(1)
 
     try:
